@@ -22,15 +22,18 @@ fi
 ##  Run Trinity to Generate Transcriptome Assemblies ##
 #######################################################
 
-## use jellyfish
-../../Trinity --seqType fq --max_memory 2G --left reads.left.fq,reads2.left.fq --right reads.right.fq,reads2.right.fq --SS_lib_type RF --CPU 4 --trimmomatic --normalize_reads --normalize_by_read_set --output trinity_trim_and_norm_outdir
-
-##### Done Running Trinity #####
-
-if [ ! $* ]; then
-    exit 0
-fi
 
+${TRINITY_HOME}/Trinity --seqType fq \
+              --max_memory 2G \
+              --left reads.left.fq,reads2.left.fq \
+              --right reads.right.fq,reads2.right.fq \
+              --SS_lib_type RF \
+              --CPU 4 \
+              --trimmomatic \
+              --normalize_reads \
+              --normalize_by_read_set \
+              --output trinity_trim_and_norm_outdir
 
 
 
+exit 0
