@@ -16,7 +16,7 @@ use Fasta_reader;
 use threads;
 use Data::Dumper;
 use COMMON;
-
+use DB_File;
 
 $ENV{PATH} = "$FindBin::Bin/../trinity-plugins/BIN:$ENV{PATH}";
 
@@ -389,6 +389,7 @@ main: {
     my @outputs;
     @checkpoints = ();
     my @threads;
+    my $thread_counter = 0;
     foreach my $info_aref (@files_need_stats) {
         my ($orig_file, $converted_file, $stats_file, $selected_entries) = @$info_aref;
 
@@ -410,9 +411,11 @@ main: {
     
         ## run in parallel
         
+        $thread_counter += 1;
         my $checkpoint_file = "$outfile.ok";
         unless (-e $checkpoint_file) {
-            my $thread = threads->create('make_normalized_reads_file', $orig_file, $seqType, $selected_entries, $outfile);
+
+            my $thread = threads->create('make_normalized_reads_file', $orig_file, $seqType, $selected_entries, $outfile, $thread_counter);
             
             push (@threads, $thread);
             push (@checkpoints, [$outfile, $checkpoint_file]);
@@ -465,10 +468,20 @@ main: {
 
 ####
 sub build_selected_index {
-    my $file = shift;
+    my ($file, $thread_count) = @_;
     
-    my %index = ();
     
+
+    my $index_href = {};
+    
+    my $tied_idx_filename = $file . ".thread-${thread_count}.idx";
+    if (-s $tied_idx_filename) {
+        unlink($tied_idx_filename);
+    }
+    
+    tie (%{$index_href}, 'DB_File', $tied_idx_filename, O_CREAT|O_RDWR, 0666, $DB_BTREE);
+    
+
     open(my $ifh, $file) || die "failed to read selected_entries file $file: $!";
     
     while (my $line = <$ifh> ) {
@@ -481,23 +494,23 @@ sub build_selected_index {
         #print STDERR "-want $line\n";
 
 
-        $index{$line} = 0;
+        $index_href->{$line} = 0;
     }
     
-    return (%index);
+    return ($index_href);
 }
 
 
 ####
 sub make_normalized_reads_file {
-    my ($source_files_aref, $seq_type, $selected_entries, $outfile) = @_;
+    my ($source_files_aref, $seq_type, $selected_entries, $outfile, $thread_count) = @_;
 
     print STDERR "-preparing to extract selected reads from: @$source_files_aref ...";
     open (my $ofh, ">$outfile") or die "Error, cannot write to $outfile";
 
     my @source_files = @$source_files_aref;
     
-    my %idx = &build_selected_index( $selected_entries );
+    my $idx_href = &build_selected_index( $selected_entries, $thread_count );
     print STDERR " done prepping, now search and capture.\n";
     
     #print STDERR Dumper(\%idx);
@@ -529,8 +542,8 @@ sub make_normalized_reads_file {
             
             #print STDERR "parsed acc: [$acc]\n";
             
-            if ( exists $idx{$acc} ) {
-                $idx{$acc}++;
+            if ( exists $idx_href->{$acc} ) {
+                $idx_href->{$acc}++;
                 my $record = '';
                 
                 if ($seqType eq 'fq') { 
@@ -547,11 +560,10 @@ sub make_normalized_reads_file {
     
     ## check and make sure they were all found
     my %missing;
-    for my $k ( keys %idx ) {
-        if ($idx{$k} == 0) {
-
+    for my $k ( keys %{$idx_href} ) {
+        if ($idx_href->{$k} == 0) {
         
-            $missing{$k} =1 ;
+            $missing{$k} = 1;
         }
         
     }
