@@ -9,11 +9,14 @@ use Fasta_reader;
 use File::Basename;
 
 
-my $usage = "usage: $0 EXPR.matrix Trinity.fasta\n\n";
+my $usage = "usage: $0 isoform.EXPR.matrix Trinity.fasta [by=transcript|gene (default:transcript)]\n\n"
+    . "\t note, use the isoform.EXPR.matrix file regardiess of wehther you choose transcript | gene feature type to explore.\n\n";
 
 
 my $matrix_file = $ARGV[0] or die $usage;
 my $fasta_file = $ARGV[1] or die $usage;
+my $by_feature_type = $ARGV[2] || "transcript";
+
 
 unless (-s $matrix_file) {
     die "Error, cannot locate matrix file: $matrix_file";
@@ -22,6 +25,10 @@ unless (-s $fasta_file) {
     die "Error, cannot locate fasta file: $fasta_file";
 }
 
+unless ($by_feature_type =~ /^(transcript|gene)$/) {
+    die "Error, cannot discern feature type: [$by_feature_type] ";
+}
+
 my %trans_lengths;
 {
     my $fasta_reader = new Fasta_reader($fasta_file);
@@ -43,6 +50,7 @@ my %gene_to_trans;
 
 my $sum_expr = 0;
 
+
 my $feature_type = "transcript";
 
 while (<$fh>) {
@@ -62,12 +70,19 @@ while (<$fh>) {
         }
     }
     
-    my $seq_len = $trans_lengths{$acc} or die "Error, no seq length for acc: $acc";
+    my $seq_len = $trans_lengths{$acc} or die "Error, no seq length for acc: $acc.  Be sure to give the isoform.TPM expression matrix as input parameter";
 
     my $gene_id = $acc;
-    if ($acc =~ /^(\S+)_i\d+/) {
-        $gene_id = $1;
-        $feature_type = "gene";
+
+    
+    if ($by_feature_type =~ /gene/) {
+        if ($acc =~ /^(\S+)_i\d+/) {
+            $gene_id = $1;
+            $feature_type = "gene";
+        }
+        else {
+            die "Error, by_feature_type is gene, but cannot extract gene_id from $acc ";
+        }
     }
     
     push (@{$gene_to_trans{$gene_id}}, { acc => $acc,
@@ -118,7 +133,7 @@ foreach my $gene (keys %gene_to_trans) {
 ## write output table
 
 
-my $E_file = basename($matrix_file) . ".E-inputs";
+my $E_file = basename($matrix_file) . ".by-$feature_type.E-inputs";
 open (my $ofh, ">$E_file") or die $!;
 print $ofh join("\t", "#Ex", "acc", "length", "max_expr_over_samples", "sum_expr_over_samples") . "\n";
 
@@ -135,7 +150,7 @@ while (@genes) {
 
     my $pct = int($sum/$sum_expr * 100);
     
-    print $ofh join("\t", $pct, $t->{acc}, int($t->{len}), sprintf("%.1f", $t->{max_expr}), sprintf("%.1f", $t->{sum_expr})) . "\n";
+    print $ofh join("\t", $pct, $t->{acc}, int($t->{len}), sprintf("%.3f", $t->{max_expr}), sprintf("%.3f", $t->{sum_expr})) . "\n";
     
     if ($prev_pct > 0 && $pct > $prev_pct) {
         
