@@ -30,6 +30,8 @@ my $usage = <<__EOUSAGE__;
 #  --star_path <string>        full path to the STAR program to use.
 #  --patch <string>            genomic targets to patch the genome fasta with.
 #  --chim_search               include Chimeric.junction outputs
+#  --max_intron <int>          max intron length (and PE gap size)
+#  --one_pass                  do one pass alignment instead of two-pass
 #
 #######################################################################
 
@@ -53,6 +55,8 @@ my $ADV = 0;
 my $star_path = "STAR";
 my $patch;
 my $chim_search;
+my $max_intron;
+my $one_pass = 0;
 
 &GetOptions( 'h' => \$help_flag,
              'genome=s' => \$genome,
@@ -65,6 +69,8 @@ my $chim_search;
              'star_path=s' => \$star_path,
              'patch=s' => \$patch,
              'chim_search' => \$chim_search,
+             "max_intron=i" => \$max_intron,
+             'one_pass' => \$one_pass,
     );
 
 
@@ -81,7 +87,7 @@ if (@ARGV) {
 }
 
 
-my $star_prog = `which $star_path`;
+my $star_prog = `sh -c "command -v $star_path"`;
 chomp $star_prog;
 unless ($star_prog =~ /\w/) {
     die "Error, cannot locate STAR program. Be sure it's in your PATH setting.  ";
@@ -140,31 +146,52 @@ main: {
     
     my $pipeliner = new Pipeliner(-verbose => 1);
 
+    my $pass_mode = ($one_pass) ? "None" : "Basic";
+
     my $cmd = "$star_prog "
         . " --runThreadN $CPU "
         . " --genomeDir $star_index "
         . " --outSAMtype BAM SortedByCoordinate "
         . " --runMode alignReads "
         . " --readFilesIn $reads "
-        . " --twopassMode Basic "
+        . " --twopassMode $pass_mode "
         . " --alignSJDBoverhangMin 10 "
         . " --outSAMstrandField intronMotif "
         . " --outSAMunmapped Within "
+        . " --outReadsUnmapped Fastx "
+        . " --alignInsertionFlush Right "
+        . " --alignSplicedMateMapLminOverLmate 0 "
+        . " --alignSplicedMateMapLmin 30 "
+        . " --alignSJstitchMismatchNmax 5 -1 5 5 "  #which allows for up to 5 mismatches for non-canonical GC/AG, and AT/AC junctions, and any number of mismatches for canonical junctions (the default values 0 -1 0 0 replicate the old behavior (from AlexD)      
+        . " --peOverlapNbasesMin 12 "
+        . " --peOverlapMMp 0.1 "
         . " --limitBAMsortRAM 20000000000";
 
+
+    if ($max_intron) {
+    
+        $cmd .= " --alignMatesGapMax $max_intron "
+            . " --alignIntronMax $max_intron ";
+    }
+    
+    
     if ($chim_search) {
-        $cmd .= " --chimJunctionOverhangMin 12 "
+        $cmd .= " --chimJunctionOverhangMin 8 "
+             .  " --chimOutJunctionFormat 1 "
              .  " --chimSegmentMin 12 "
              .  " --chimSegmentReadGapMax parameter 3 "
+             .  " --chimMultimapNmax 20 "
+             .  " --chimOutType Junctions WithinBAM "
+             .  " --chimScoreJunctionNonGTAG -4 "
+             .  " --chimNonchimScoreDropMin 10 "
+             .  " --chimMultimapScoreRange 10 ";
     }
-        
+    
     if ($patch) {
         $cmd .= " --genomeFastaFiles $patch ";
     }
         
-    
-    $cmd .= " --alignSJstitchMismatchNmax 5 -1 5 5 ";  #which allows for up to 5 mismatches for non-canonical GC/AG, and AT/AC junctions, and any number of mismatches for canonical junctions (the default values 0 -1 0 0 replicate the old behavior (from AlexD)
-    
+        
     
     if ($reads =~ /\.gz$/) {
         $cmd .= " --readFilesCommand 'gunzip -c' ";
